%Plot blank axes for compound pendulum analysis graph (model period vs measured period).

function cpendulum_graphs

%Fontsize
fsize = 18;

%Tickmarks
xticks = 1: 0.2: 2;
yticks = 1: 0.2: 2;
xminorticks = 1: 0.02: 2;
yminorticks = 1: 0.02: 2;

%Create axes
[fig,ax] = cleargridaxes( xticks,yticks, xminorticks, yminorticks, fsize );
xlabel('Model period /s'); ylabel('Measured period /s');
title('Compound pendulum. Model vs measured period.');

%Save PNG file and close
print(gcf,'cpendulum_blank_axes.png','-r300','-dpng');
close(gcf);

%%

%Graph axes with clear grid lines
function [fig,ax] = cleargridaxes( xticks,yticks, xminorticks, yminorticks, fsize )
fig = figure('color',[1 1 1]);
ax = axes('fontsize',fsize,'nextplot','add');
xlim([xticks(1),xticks(end)]);
ylim([yticks(1),yticks(end)]); axis manual; box on;
set(gca,'xtick',xticks,'ytick',yticks);
for n=1:length(xminorticks);
    plot( xminorticks(n)*[1,1], [yticks(1),yticks(end)],'k-' );
end
for n=1:length(yminorticks);
    plot( [xticks(1),xticks(end)], yminorticks(n)*[1,1],'k-' );
end
for n=1:length(xticks);
    plot( xticks(n)*[1,1], [yticks(1),yticks(end)],'k-','linewidth',2 );
end
for n=1:length(yticks);
    plot( [xticks(1),xticks(end)], yticks(n)*[1,1],'k-','linewidth',2 );
end

%End of code


